==> jc-1.4.5.tar.gz: org/omg/CORBA/StringHolder.h <==
// public final class org.omg.CORBA.StringHolder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 87efed8f870af714 org_omg_CORBA_StringHolder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_omg_CORBA_StringHolder_H_
#define _JC_org_omg_CORBA_StringHolder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_omg_CORBA_TypeCode$object;
struct _jc_org_omg_CORBA_portable_InputStream$object;
struct _jc_org_omg_CORBA_portable_OutputStream$object;

// Typedefs
typedef struct _jc_org_omg_CORBA_StringHolder$sub_refs	_jc_org_omg_CORBA_StringHolder$sub_refs;
typedef struct _jc_org_omg_CORBA_StringHolder$sub_nonrefs	_jc_org_omg_CORBA_StringHolder$sub_nonrefs;
typedef struct _jc_org_omg_CORBA_StringHolder$refs	_jc_org_omg_CORBA_StringHolder$refs;
typedef struct _jc_org_omg_CORBA_StringHolder$nonrefs	_jc_org_omg_CORBA_StringHolder$nonrefs;
typedef struct _jc_org_omg_CORBA_StringHolder$object	_jc_org_omg_CORBA_StringHolder$object;

typedef struct _jc_org_omg_CORBA_StringHolder$fields_struct	_jc_org_omg_CORBA_StringHolder$fields_struct;
typedef const struct _jc_org_omg_CORBA_StringHolder$vmethods	_jc_org_omg_CORBA_StringHolder$vmethods;
typedef const struct _jc_org_omg_CORBA_StringHolder$vtable	_jc_org_omg_CORBA_StringHolder$vtable;
typedef const struct _jc_org_omg_CORBA_StringHolder$vtype	_jc_org_omg_CORBA_StringHolder$vtype;

// Class fields structure
struct _jc_org_omg_CORBA_StringHolder$fields_struct {
	struct _jc_org_omg_CORBA_TypeCode$object	*t__5fstring;
};
extern _jc_org_omg_CORBA_StringHolder$fields_struct _jc_org_omg_CORBA_StringHolder$class_fields;

// Constructors
extern void _jc_org_omg_CORBA_StringHolder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_omg_CORBA_StringHolder$object *) _JC_JCNI_ATTR;
extern void _jc_org_omg_CORBA_StringHolder$method$_init$c31b894660454d13(_jc_env *, struct _jc_org_omg_CORBA_StringHolder$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_org_omg_CORBA_StringHolder$method$__5fread$c7aa38a2dd990991(_jc_env *, struct _jc_org_omg_CORBA_StringHolder$object *, struct _jc_org_omg_CORBA_portable_InputStream$object *) _JC_JCNI_ATTR;
extern struct _jc_org_omg_CORBA_TypeCode$object *_jc_org_omg_CORBA_StringHolder$method$__5ftype$ae49d288997e6b59(_jc_env *, struct _jc_org_omg_CORBA_StringHolder$object *) _JC_JCNI_ATTR;
extern void _jc_org_omg_CORBA_StringHolder$method$__5fwrite$2acedd4e48d3efc7(_jc_env *, struct _jc_org_omg_CORBA_StringHolder$object *, struct _jc_org_omg_CORBA_portable_OutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_omg_CORBA_StringHolder$method_info$__5fread$c7aa38a2dd990991;
extern _jc_method _jc_org_omg_CORBA_StringHolder$method_info$__5ftype$ae49d288997e6b59;
extern _jc_method _jc_org_omg_CORBA_StringHolder$method_info$__5fwrite$2acedd4e48d3efc7;

// Static methods
extern void _jc_org_omg_CORBA_StringHolder$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_omg_CORBA_StringHolder$vmethods {
	void	(*__5fread$c7aa38a2dd990991)(_jc_env *, struct _jc_org_omg_CORBA_StringHolder$object *, struct _jc_org_omg_CORBA_portable_InputStream$object *) _JC_JCNI_ATTR;
	struct _jc_org_omg_CORBA_TypeCode$object	*(*__5ftype$ae49d288997e6b59)(_jc_env *, struct _jc_org_omg_CORBA_StringHolder$object *) _JC_JCNI_ATTR;
	void	(*__5fwrite$2acedd4e48d3efc7)(_jc_env *, struct _jc_org_omg_CORBA_StringHolder$object *, struct _jc_org_omg_CORBA_portable_OutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_omg_CORBA_StringHolder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_omg_CORBA_StringHolder$vmethods	org_omg_CORBA_StringHolder;
};

// Vtype
struct _jc_org_omg_CORBA_StringHolder$vtype {
	_jc_type			type;
	_jc_org_omg_CORBA_StringHolder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_omg_CORBA_StringHolder$sub_refs {
	struct _jc_java_lang_String$object	*value;
};

// Reference instance fields (object)
struct _jc_org_omg_CORBA_StringHolder$refs {
    _jc_org_omg_CORBA_StringHolder$sub_refs	org_omg_CORBA_StringHolder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_omg_CORBA_StringHolder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_omg_CORBA_StringHolder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_omg_CORBA_StringHolder$sub_nonrefs	org_omg_CORBA_StringHolder;
};

// Object instance structure
struct _jc_org_omg_CORBA_StringHolder$object {
	_jc_org_omg_CORBA_StringHolder$refs	refs[0];
	_jc_word		lockword;
	_jc_org_omg_CORBA_StringHolder$vtype	*vtype;
	_jc_org_omg_CORBA_StringHolder$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_omg_CORBA_StringHolder$vtype _jc_org_omg_CORBA_StringHolder$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_omg_CORBA_StringHolder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_omg_CORBA_StringHolder$class_object;

#endif	/* _JC_org_omg_CORBA_StringHolder_H_ */

==> jc-1.4.6.tar.gz: org/omg/CORBA/StringHolder.h <==
// public final class org.omg.CORBA.StringHolder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 386567f9fcc20c05 org_omg_CORBA_StringHolder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_omg_CORBA_StringHolder_H_
#define _JC_org_omg_CORBA_StringHolder_H_

// Forward structure declarations
struct _jc_gnu_CORBA_stringTypeCode$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_omg_CORBA_TypeCode$object;
struct _jc_org_omg_CORBA_portable_InputStream$object;
struct _jc_org_omg_CORBA_portable_OutputStream$object;

// Typedefs
typedef struct _jc_org_omg_CORBA_StringHolder$sub_refs	_jc_org_omg_CORBA_StringHolder$sub_refs;
typedef struct _jc_org_omg_CORBA_StringHolder$sub_nonrefs	_jc_org_omg_CORBA_StringHolder$sub_nonrefs;
typedef struct _jc_org_omg_CORBA_StringHolder$refs	_jc_org_omg_CORBA_StringHolder$refs;
typedef struct _jc_org_omg_CORBA_StringHolder$nonrefs	_jc_org_omg_CORBA_StringHolder$nonrefs;
typedef struct _jc_org_omg_CORBA_StringHolder$object	_jc_org_omg_CORBA_StringHolder$object;

typedef struct _jc_org_omg_CORBA_StringHolder$fields_struct	_jc_org_omg_CORBA_StringHolder$fields_struct;
typedef const struct _jc_org_omg_CORBA_StringHolder$vmethods	_jc_org_omg_CORBA_StringHolder$vmethods;
typedef const struct _jc_org_omg_CORBA_StringHolder$vtable	_jc_org_omg_CORBA_StringHolder$vtable;
typedef const struct _jc_org_omg_CORBA_StringHolder$vtype	_jc_org_omg_CORBA_StringHolder$vtype;

// Class fields structure
struct _jc_org_omg_CORBA_StringHolder$fields_struct {
	struct _jc_gnu_CORBA_stringTypeCode$object	*t__5fstring;
};
extern _jc_org_omg_CORBA_StringHolder$fields_struct _jc_org_omg_CORBA_StringHolder$class_fields;

// Constructors
extern void _jc_org_omg_CORBA_StringHolder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_omg_CORBA_StringHolder$object *) _JC_JCNI_ATTR;
extern void _jc_org_omg_CORBA_StringHolder$method$_init$c31b894660454d13(_jc_env *, struct _jc_org_omg_CORBA_StringHolder$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_org_omg_CORBA_StringHolder$method$__5fread$c7aa38a2dd990991(_jc_env *, struct _jc_org_omg_CORBA_StringHolder$object *, struct _jc_org_omg_CORBA_portable_InputStream$object *) _JC_JCNI_ATTR;
extern struct _jc_org_omg_CORBA_TypeCode$object *_jc_org_omg_CORBA_StringHolder$method$__5ftype$ae49d288997e6b59(_jc_env *, struct _jc_org_omg_CORBA_StringHolder$object *) _JC_JCNI_ATTR;
extern void _jc_org_omg_CORBA_StringHolder$method$__5fwrite$2acedd4e48d3efc7(_jc_env *, struct _jc_org_omg_CORBA_StringHolder$object *, struct _jc_org_omg_CORBA_portable_OutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_omg_CORBA_StringHolder$method_info$__5fread$c7aa38a2dd990991;
extern _jc_method _jc_org_omg_CORBA_StringHolder$method_info$__5ftype$ae49d288997e6b59;
extern _jc_method _jc_org_omg_CORBA_StringHolder$method_info$__5fwrite$2acedd4e48d3efc7;

// Static methods
extern void _jc_org_omg_CORBA_StringHolder$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_omg_CORBA_StringHolder$vmethods {
	void	(*__5fread$c7aa38a2dd990991)(_jc_env *, struct _jc_org_omg_CORBA_StringHolder$object *, struct _jc_org_omg_CORBA_portable_InputStream$object *) _JC_JCNI_ATTR;
	struct _jc_org_omg_CORBA_TypeCode$object	*(*__5ftype$ae49d288997e6b59)(_jc_env *, struct _jc_org_omg_CORBA_StringHolder$object *) _JC_JCNI_ATTR;
	void	(*__5fwrite$2acedd4e48d3efc7)(_jc_env *, struct _jc_org_omg_CORBA_StringHolder$object *, struct _jc_org_omg_CORBA_portable_OutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_omg_CORBA_StringHolder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_omg_CORBA_StringHolder$vmethods	org_omg_CORBA_StringHolder;
};

// Vtype
struct _jc_org_omg_CORBA_StringHolder$vtype {
	_jc_type			type;
	_jc_org_omg_CORBA_StringHolder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_omg_CORBA_StringHolder$sub_refs {
	struct _jc_java_lang_String$object	*value;
};

// Reference instance fields (object)
struct _jc_org_omg_CORBA_StringHolder$refs {
    _jc_org_omg_CORBA_StringHolder$sub_refs	org_omg_CORBA_StringHolder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_omg_CORBA_StringHolder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_omg_CORBA_StringHolder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_omg_CORBA_StringHolder$sub_nonrefs	org_omg_CORBA_StringHolder;
};

// Object instance structure
struct _jc_org_omg_CORBA_StringHolder$object {
	_jc_org_omg_CORBA_StringHolder$refs	refs[0];
	_jc_word		lockword;
	_jc_org_omg_CORBA_StringHolder$vtype	*vtype;
	_jc_org_omg_CORBA_StringHolder$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_omg_CORBA_StringHolder$vtype _jc_org_omg_CORBA_StringHolder$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_omg_CORBA_StringHolder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_omg_CORBA_StringHolder$class_object;

#endif	/* _JC_org_omg_CORBA_StringHolder_H_ */
